
# Slot: is_a




URI: [linkml:slot_definition_is_a](https://w3id.org/linkml/slot_definition_is_a)


## Domain and Range

slot_definition &#8594;  <sub>0..1</sub> slot_definition

## Parents

 *  is_a: is_a

## Children


## Used by

 * slot_definition
